diff --git a/bdk/power/regulator_5v.c b/bdk/power/regulator_5v.c
index 7b8924b..379f7a6 100644
--- a/bdk/power/regulator_5v.c
+++ b/bdk/power/regulator_5v.c
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2019 CTCaer
+ * Copyright (c) 2019-2021 CTCaer
*
* This program is free software; you can redistribute it and/or modify it
* under the terms and conditions of the GNU General Public License,
@@ -14,7 +14,9 @@
* along with this program. If not, see .
*/
+#include
#include
+#include
#include
#include
#include
@@ -34,17 +36,30 @@ void regulator_5v_enable(u8 dev)
gpio_output_enable(GPIO_PORT_A, GPIO_PIN_5, GPIO_OUTPUT_ENABLE);
gpio_write(GPIO_PORT_A, GPIO_PIN_5, GPIO_HIGH);
- // Fan and Rail power from USB 5V VBUS.
- PINMUX_AUX(PINMUX_AUX_USB_VBUS_EN0) = PINMUX_LPDR | 1;
- gpio_config(GPIO_PORT_CC, GPIO_PIN_4, GPIO_MODE_GPIO);
- gpio_output_enable(GPIO_PORT_CC, GPIO_PIN_4, GPIO_OUTPUT_ENABLE);
- gpio_write(GPIO_PORT_CC, GPIO_PIN_4, GPIO_LOW);
- usb_src = false;
+ // Only Icosa and Iowa have USB 5V VBUS rails. Skip on Hoag/Aula.
+ u32 hw_type = fuse_read_hw_type();
+ if (hw_type == FUSE_NX_HW_TYPE_ICOSA ||
+ hw_type == FUSE_NX_HW_TYPE_IOWA)
+ {
+ // Fan and Rail power from USB 5V VBUS.
+ PINMUX_AUX(PINMUX_AUX_USB_VBUS_EN0) = PINMUX_LPDR | 1;
+ gpio_config(GPIO_PORT_CC, GPIO_PIN_4, GPIO_MODE_GPIO);
+ gpio_output_enable(GPIO_PORT_CC, GPIO_PIN_4, GPIO_OUTPUT_ENABLE);
+ gpio_write(GPIO_PORT_CC, GPIO_PIN_4, GPIO_LOW);
+ }
- // Make sure GPIO power is enabled.
- PMC(APBDEV_PMC_NO_IOPOWER) &= ~PMC_NO_IOPOWER_GPIO_IO_EN;
- // Override power detect for GPIO AO IO rails.
- PMC(APBDEV_PMC_PWR_DET_VAL) &= ~PMC_PWR_DET_GPIO_IO_EN;
+ // Enable GPIO AO IO rail for T210.
+ if (hw_get_chip_id() == GP_HIDREV_MAJOR_T210)
+ {
+ // Make sure GPIO power is enabled.
+ PMC(APBDEV_PMC_NO_IOPOWER) &= ~PMC_NO_IOPOWER_GPIO_IO_EN;
+ (void)PMC(APBDEV_PMC_NO_IOPOWER); // Commit write.
+
+ // Override power detect for GPIO AO IO rails.
+ PMC(APBDEV_PMC_PWR_DET_VAL) &= ~PMC_PWR_DET_GPIO_IO_EN;
+ (void)PMC(APBDEV_PMC_PWR_DET_VAL); // Commit write.
+ }
+ usb_src = false;
}
reg_5v_dev |= dev;
}
@@ -61,15 +76,26 @@ void regulator_5v_disable(u8 dev)
gpio_config(GPIO_PORT_A, GPIO_PIN_5, GPIO_MODE_SPIO);
PINMUX_AUX(PINMUX_AUX_SATA_LED_ACTIVE) = PINMUX_PARKED | PINMUX_INPUT_ENABLE;
- // Rail power from USB 5V VBUS.
- gpio_write(GPIO_PORT_CC, GPIO_PIN_4, GPIO_LOW);
- gpio_output_enable(GPIO_PORT_CC, GPIO_PIN_4, GPIO_OUTPUT_DISABLE);
- gpio_config(GPIO_PORT_CC, GPIO_PIN_4, GPIO_MODE_SPIO);
- PINMUX_AUX(PINMUX_AUX_USB_VBUS_EN0) = PINMUX_IO_HV | PINMUX_LPDR | PINMUX_PARKED | PINMUX_INPUT_ENABLE;
- usb_src = false;
+ // Only Icosa and Iowa have USB 5V VBUS rails. Skip on Hoag/Aula.
+ u32 hw_type = fuse_read_hw_type();
+ if (hw_type == FUSE_NX_HW_TYPE_ICOSA ||
+ hw_type == FUSE_NX_HW_TYPE_IOWA)
+ {
+ // Rail power from USB 5V VBUS.
+ gpio_write(GPIO_PORT_CC, GPIO_PIN_4, GPIO_LOW);
+ gpio_output_enable(GPIO_PORT_CC, GPIO_PIN_4, GPIO_OUTPUT_DISABLE);
+ gpio_config(GPIO_PORT_CC, GPIO_PIN_4, GPIO_MODE_SPIO);
+ PINMUX_AUX(PINMUX_AUX_USB_VBUS_EN0) = PINMUX_IO_HV | PINMUX_LPDR | PINMUX_PARKED | PINMUX_INPUT_ENABLE;
+ usb_src = false;
+
+ }
// GPIO AO IO rails.
- PMC(APBDEV_PMC_PWR_DET_VAL) |= PMC_PWR_DET_GPIO_IO_EN;
+ if (hw_get_chip_id() == GP_HIDREV_MAJOR_T210)
+ {
+ PMC(APBDEV_PMC_PWR_DET_VAL) |= PMC_PWR_DET_GPIO_IO_EN;
+ (void)PMC(APBDEV_PMC_PWR_DET_VAL); // Commit write.
+ }
}
}
@@ -80,6 +106,12 @@ bool regulator_5v_get_dev_enabled(u8 dev)
void regulator_5v_usb_src_enable(bool enable)
{
+ // Only for Icosa/Iowa. Skip on Hoag/Aula.
+ u32 hw_type = fuse_read_hw_type();
+ if (hw_type != FUSE_NX_HW_TYPE_ICOSA &&
+ hw_type != FUSE_NX_HW_TYPE_IOWA)
+ return;
+
if (enable && !usb_src)
{
gpio_write(GPIO_PORT_CC, GPIO_PIN_4, GPIO_HIGH);